const nsIFilePicker = Components.interfaces.nsIFilePicker;
const nsIPrefBranchInternal = Components.interfaces.nsIPrefBranchInternal;

const prefService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
const promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
const strBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"].getService(Components.interfaces.nsIStringBundleService);
const uniConverter = Components.classes["@mozilla.org/intl/scriptableunicodeconverter"].createInstance(Components.interfaces.nsIScriptableUnicodeConverter);
const winMediator = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);

const prefBranch = prefService.getBranch("extensions.msnmsgr.");
const XHTML = "http://www.w3.org/1999/xhtml";

const NS_ERROR_MODULE_NETWORK = 2152398848;
const NS_ERROR_MODULE_FILES = 2152857600;

uniConverter.charset = "UTF-8";

function getStringBundle(path) {
  return strBundleService.createBundle(path); 
}

function getPref(func, pref, defaultValue) {
  try {
    return prefBranch[func](pref);
  }
  catch (ex) {
    return defaultValue;
  }
}

function openWindowOnce(url, type, features) {
  var recentWindow = winMediator.getMostRecentWindow(type);
  if (recentWindow != null) {
    recentWindow.focus();
  }
  else {
    window.openDialog(url, type, features);
  }
}

function parseHeaders(headers) {
  var header = headers.split('\r\n');
  return parseFields(header, ": ");
}

function parseFields(fields, splitString) {
  var parsedFields = new Array();
  for (var field in fields) {
    var parsedField = fields[field].split(splitString);
    parsedFields[parsedField[0].toLowerCase()] = parsedField[1];
  }
  return parsedFields;
}

function uniConvertTo(chunk) {
  return uniConverter.ConvertToUnicode(chunk);
}

function uniConvertFrom(chunk) {
  return uniConverter.ConvertFromUnicode(chunk);
}